@@ -36,84 +36,148 @@ defined('_JEXEC') or die('Restricted access');
  */
 class WishlistPlan extends JTable
 {
+	/**
+	 * int(11) Primary key
+	 * 
+	 * @var integer
+	 */
+	var $id         = NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $wishid		= NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $version	= NULL;
+
+	/**
+	 * datetime(0000-00-00 00:00:00)
+	 * 
+	 * @var string
+	 */
+	var $created	= NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $created_by	= NULL;
+
+	/**
+	 * int(1)
+	 * 
+	 * @var integer
+	 */
+	var $minor_edit	= NULL;
+
+	/**
+	 * text
+	 * 
+	 * @var string
+	 */
+	var $pagetext	= NULL;
+
+	/**
+	 * text
+	 * 
+	 * @var string
+	 */
+	var $pagehtml	= NULL;
+
+	/**
+	 * int(1)
+	 * 
+	 * @var integer
+	 */
+	var $approved   = NULL;
+
+	/**
+	 * varchar(255)
+	 * 
+	 * @var string
+	 */
+	var $summary	= NULL;
+
 	/**
 	 * Constructor
-	 *
-	 * @param   object  &$db  JDatabase
-	 * @return  void
+	 * 
+	 * @param      object &$db JDatabase
+	 * @return     void
 	 */
 	public function __construct(&$db)
 	{
 		parent::__construct('#__wishlist_implementation', 'id', $db);
 	}
 
-	/**
-	 * Validate data
-	 *
-	 * @return  boolean  True if data is valid
-	 */
-	public function check()
-	{
-		$this->pagetext = rtrim($this->pagetext);
-		if (!$this->pagetext)
-		{
-			$this->setError(JText::_('Please provide a plan'));
-			return false;
-		}
-
-		$this->version = intval($this->version);
-
-		$this->wishid = intval($this->wishid);
-		if (!$this->wishid)
-		{
-			$this->setError(JText::_('Please provide a wish ID'));
-			return false;
-		}
-
-		if (!$this->id)
-		{
-			$this->created    = JFactory::getDate()->toSql();
-			$this->created_by = JFactory::getUser()->get('id');
-		}
-
-		return true;
-	}
-
 	/**
 	 * Get a record for a wish
-	 *
-	 * @param   integer  $wishid  Wish ID
-	 * @return  mixed    False if error, array on success
+	 * 
+	 * @param      integer $wishid Wish ID
+	 * @return     mixed False if error, array on success
 	 */
 	public function getPlan($wishid)
 	{
-		if ($wishid == NULL)
+		if ($wishid == NULL) 
 		{
 			return false;
 		}
 
-		$query  = "SELECT *, xp.name AS authorname 
-					FROM `#__wishlist_implementation` AS p 
-					LEFT JOIN `#__xprofiles` AS xp ON xp.uidNumber=p.created_by 
-					WHERE p.wishid = " . $this->_db->Quote($wishid) . " ORDER BY p.created DESC LIMIT 1";
+		$query  = "SELECT *, xp.name AS authorname ";
+		$query .= "FROM #__wishlist_implementation AS p  ";
+		$query .= "JOIN #__xprofiles AS xp ON xp.uidNumber=p.created_by ";
+		$query .= "WHERE p.wishid = '" . $wishid . "' ORDER BY p.created DESC LIMIT 1";
 		$this->_db->setQuery($query);
 		return $this->_db->loadObjectList();
 	}
 
 	/**
-	 * Delete a record based on wish
-	 *
-	 * @param   integer  $wishid  Wish ID
-	 * @return  boolean  False if errors, True on success
+	 * Get a record and bind to $this
+	 * 
+	 * @param      integer $oid Record ID
+	 * @return     boolean True on success
 	 */
-	public function deletePlan($wishid)
+	public function load($oid=NULL)
 	{
-		if ($wishid == NULL)
+		if ($oid == NULL or !is_numeric($oid)) 
 		{
 			return false;
 		}
 
-		$this->_db->setQuery("DELETE FROM $this->_tbl WHERE wishid=" . $this->_db->Quote($wishid));
+		$this->_db->setQuery("SELECT * FROM $this->_tbl WHERE id='$oid'");
+		if ($result = $this->_db->loadAssoc()) 
+		{
+			return $this->bind($result);
+		} 
+		else 
+		{
+			$this->setError($this->_db->getErrorMsg());
+			return false;
+		}
+	}
+
+	/**
+	 * Delete a record based on wish
+	 * 
+	 * @param      integer $wishid Wish ID
+	 * @return     boolean False if errors, True on success
+	 */
+	public function deletePlan($wishid)
+	{
+		if ($wishid == NULL) 
+		{
+			return false;
+		}
+
+		$query = "DELETE FROM $this->_tbl WHERE wishid='" . $wishid . "'";
+		$this->_db->setQuery($query);
 		$this->_db->query();
 		return true;
 	}
