@@ -40,21 +40,21 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 {
 	/**
 	 * Mime type
-	 *
+	 * 
 	 * @var string
 	 */
 	protected $_mime = 'application/x-endnote-refer';
 
 	/**
 	 * File extension
-	 *
+	 * 
 	 * @var string
 	 */
 	protected $_extension = 'enw';
 
 	/**
 	 * Format the file
-	 *
+	 * 
 	 * @param      object $row Record to format
 	 * @return     string
 	 */
@@ -69,8 +69,14 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 		}
 		$exclude = array_values(array_filter(array_map('trim', explode("\n", $exclude))));
 
+		$paramsClass = 'JParameter';
+		if (version_compare(JVERSION, '1.6', 'ge'))
+		{
+			$paramsClass = 'JRegistry';
+		}
+
 		//get fields to not include for specific citation
-		$cparams = new JRegistry($row->params);
+		$cparams = new $paramsClass($row->params);
 		$citation_exclude = $cparams->get('exclude', '');
 		if (strpos($citation_exclude, ',') !== false)
 		{
@@ -85,14 +91,14 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 		$doc = '';
 
 		//get all the citation types
-		$db = JFactory::getDBO();
+		$db =& JFactory::getDBO();
 		$ct = new CitationsType($db);
 		$types = $ct->getType();
 
 		$type = '';
-		foreach ($types as $t)
+		foreach($types as $t) 
 		{
-			if ($t['id'] == $row->type)
+			if ($t['id'] == $row->type) 
 			{
 				$type = $t['type_title'];
 			}
@@ -104,13 +110,13 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 		//set the type
 		$doc .= "%0 {$type}" . "\r\n";
 
-		if ($row->booktitle && !in_array('booktitle', $exclude))
+		if ($row->booktitle && !in_array('booktitle', $exclude)) 
 		{
 			$bt = html_entity_decode($row->booktitle);
 			$bt = (!preg_match('!\S!u', $bt)) ? utf8_encode($bt) : $bt;
 			$doc .= "%B " . $bt . "\r\n";
 		}
-		if ($row->journal && !in_array('journal', $exclude))
+		if ($row->journal && !in_array('journal', $exclude)) 
 		{
 			$j = html_entity_decode($row->journal);
 			$j = (!preg_match('!\S!u', $j)) ? utf8_encode($j) : $j;
@@ -130,12 +136,12 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 		{
 			$author = html_entity_decode($row->author);
 			$author = (!preg_match('!\S!u', $author)) ? utf8_encode($author) : $author;
-
+			
 			$author_array = explode(';', stripslashes($author));
 			foreach ($author_array as $auth)
 			{
 				$auth = preg_replace('/{{(.*?)}}/s', '', $auth);
-				if (!strstr($auth, ','))
+				if (!strstr($auth, ',')) 
 				{
 					$bits = explode(' ', $auth);
 					$n = array_pop($bits) . ', ';
@@ -149,18 +155,18 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 		{
 			$doc .= "%C " . htmlspecialchars_decode(trim(stripslashes($row->address))) . "\r\n";
 		}
-		if ($row->editor && !in_array('editor', $exclude))
+		if ($row->editor && !in_array('editor', $exclude)) 
 		{
 			$editor = html_entity_decode($row->editor);
 			$editor = (!preg_match('!\S!u', $editor)) ? utf8_encode($editor) : $editor;
-
+			
 			$author_array = explode(';', stripslashes($editor));
 			foreach ($author_array as $auth)
 			{
 				$doc .= "%E " . trim($auth) . "\r\n";
 			}
 		}
-		if ($row->publisher && !in_array('publisher', $exclude))
+		if ($row->publisher && !in_array('publisher', $exclude)) 
 		{
 			$p = html_entity_decode($row->publisher);
 			$p = (!preg_match('!\S!u', $p)) ? utf8_encode($p) : $p;
@@ -256,33 +262,6 @@ class CitationsDownloadEndnote extends CitationsDownloadAbstract
 			$st = (!preg_match('!\S!u', $st)) ? utf8_encode($st) : $st;
 			$doc .= "%! " . htmlspecialchars_decode(trim($st)) . "\r\n";
 		}
-
-		//get the endnote import params
-		//we want to get the endnote key used for importing badges to export them
-		$endnote_import_plugin_params = \Hubzero\Plugin\Plugin::getParams( 'endnote', 'citation' );
-		$custom_tags = explode("\n", $endnote_import_plugin_params->get('custom_tags'));
-
-		$citation_endnote_tags = array();
-		$citation_badges_key = "";
-		foreach ($custom_tags  as $ct)
-		{
-			$citation_endnote_tags[] = explode("-", trim($ct));
-		}
-
-		foreach ($citation_endnote_tags as $cet)
-		{
-			if ($cet[0] == 'badges')
-			{
-				$citation_badges_key = $cet[1];
-			}
-		}
-
-		//if we found a key to export badges then add to export
-		if ($row->badges && !in_array('badges', $exclude) && $citation_badges_key != '')
-		{
-			$doc .= $citation_badges_key . " " . $row->badges;
-		}
-
 		$doc .= "\r\n";
 		return $doc;
 	}
