@@ -31,23 +31,65 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
-require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'models' . DS . 'cloud.php');
+require_once(JPATH_ROOT . DS . 'components' . DS . 'com_tags' . DS . 'helpers' . DS . 'handler.php');
 
 /**
  * Resources Tagging class
  */
-class ResourcesTags extends TagsModelCloud
+class ResourcesTags extends TagsHandler
 {
 	/**
-	 * Object type, used for linking objects (such as resources) to tags
-	 *
-	 * @var string
+	 * Constructor
+	 * 
+	 * @param      object $db     JDatabase
+	 * @param      array  $config Optional configurations
+	 * @return     void
 	 */
-	protected $_scope = 'resources';
+	public function __construct($db, $config=array())
+	{
+		$this->_db  = $db;
+		$this->_tbl = 'resources';
+	}
+
+	/**
+	 * Get tags on a resource
+	 * 
+	 * @param      integer $id        Resource ID
+	 * @param      integer $tagger_id Tagger ID
+	 * @param      integer $strength  Tag strength
+	 * @param      integer $admin     Admin flag
+	 * @return     array
+	 */
+	public function getTags($id, $tagger_id=0, $strength=0, $admin=0)
+	{
+		$sql = "SELECT DISTINCT t.* FROM $this->_tag_tbl AS t, $this->_obj_tbl AS rt WHERE ";
+
+		$where = array();
+		$where[] = "rt.objectid=$id";
+		$where[] = "rt.tbl='$this->_tbl'";
+		$where[] = "rt.tagid=t.id";
+		if ($admin != 1) 
+		{
+			$where[] = "t.admin=0";
+		}
+		if ($tagger_id != 0) 
+		{
+			$where[] = "rt.taggerid=" . $tagger_id;
+		}
+		if ($strength) 
+		{
+			$where[] = "rt.strength=" . $strength;
+		}
+
+		$sql .= implode(" AND ", $where) . " ORDER BY t.raw_tag";
+
+		$this->_db->setQuery($sql);
+		return $this->_db->loadObjectList();
+	}
 
 	/**
 	 * Get all tags with a resource association
-	 *
+	 * 
 	 * @param      integer $id   Resource ID
 	 * @param      integer $type Resource type (optional)
 	 * @param      string  $tag  Parameter description (if any) ...
@@ -55,14 +97,14 @@ class ResourcesTags extends TagsModelCloud
 	 */
 	public function get_tags_with_objects($id=0, $type=0, $tag='')
 	{
-		$juser = JFactory::getUser();
-		$now = JFactory::getDate()->toSql();
+		$juser =& JFactory::getUser();
+		$now = date('Y-m-d H:i:s', time());
 
-		$this->_db->setQuery("SELECT objectid FROM `#__tags` AS t, `#__tags_object` AS o WHERE o.tagid=t.id AND t.tag='$tag' AND o.tbl='$this->_scope'");
+		$this->_db->setQuery("SELECT objectid FROM $this->_tag_tbl AS t, $this->_obj_tbl AS o WHERE o.tagid=t.id AND t.tag='$tag' AND o.tbl='$this->_tbl'");
 		$objs = $this->_db->loadObjectList();
 
 		$ids = '';
-		if ($objs)
+		if ($objs) 
 		{
 			$s = array();
 			foreach ($objs as $obj)
@@ -72,32 +114,33 @@ class ResourcesTags extends TagsModelCloud
 			$ids = implode(',', $s);
 		}
 
-		$sql = "SELECT t.id, t.tag, t.raw_tag, r.id AS rid, 0 AS ucount, NULL AS rids
-				FROM `#__tags` AS t, `#__tags_object` AS o, `#__resources` AS r
-				WHERE o.tbl='$this->_scope'
-				AND o.tagid=t.id
-				AND t.admin=0
-				AND o.objectid=r.id
-				AND r.published=1
+		$sql = "SELECT t.id, t.tag, t.raw_tag, r.id AS rid, 0 AS ucount, NULL AS rids 
+				FROM $this->_tag_tbl AS t, $this->_obj_tbl AS o, #__resources AS r
+				WHERE o.tbl='$this->_tbl' 
+				AND o.tagid=t.id 
+				AND t.admin=0 
+				AND o.objectid=r.id 
+				AND r.published=1 
 				AND r.standalone=1
-				AND (r.publish_up = '0000-00-00 00:00:00' OR r.publish_up <= '$now')
+				AND (r.publish_up = '0000-00-00 00:00:00' OR r.publish_up <= '$now') 
 				AND (r.publish_down = '0000-00-00 00:00:00' OR r.publish_down >= '$now') ";
-		if ($type)
+		if ($type) 
 		{
 			$sql .= "AND r.type=" . $type . " ";
 		}
 
-		if (!$juser->get('guest'))
+		if (!$juser->get('guest')) 
 		{
-			$xgroups = \Hubzero\User\Helper::getGroups($juser->get('id'), 'all');
-			if ($xgroups != '')
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($juser->get('id'), 'all');
+			if ($xgroups != '') 
 			{
-				$usersgroups = self::getUsersGroups($xgroups);
-				if (count($usersgroups) > 1)
+				$usersgroups = $this->getUsersGroups($xgroups);
+				if (count($usersgroups) > 1) 
 				{
 					$groups = implode("','", $usersgroups);
-				}
-				else
+				} 
+				else 
 				{
 					$groups = count($usersgroups) ? $usersgroups[0] : '';
 				}
@@ -107,17 +150,17 @@ class ResourcesTags extends TagsModelCloud
 					$sql .= " OR r.group_access LIKE '%;" . $group . ";%'";
 				}
 				$sql .= "))) ";
-			}
-			else
+			} 
+			else 
 			{
 				$sql .= "AND (r.access=0 OR r.access=1 OR r.access=3) ";
 			}
-		}
-		else
+		} 
+		else 
 		{
 			$sql .= "AND (r.access=0 OR r.access=3) ";
 		}
-		if ($ids)
+		if ($ids) 
 		{
 			$sql .= "AND o.objectid IN ($ids) ";
 		}
@@ -127,19 +170,19 @@ class ResourcesTags extends TagsModelCloud
 		$results = $this->_db->loadObjectList();
 
 		$rows = array();
-		if ($results)
+		if ($results) 
 		{
 			foreach ($results as $result)
 			{
-				if (!isset($rows[$result->id]))
+				if (!isset($rows[$result->id])) 
 				{
 					$rows[$result->id] = $result;
 					$rows[$result->id]->ucount++;
 					$rows[$result->id]->rids = array($result->rid);
-				}
-				else
+				} 
+				else 
 				{
-					if (!in_array($result->rid, $rows[$result->id]->rids))
+					if (!in_array($result->rid, $rows[$result->id]->rids)) 
 					{
 						$rows[$result->id]->ucount++;
 						$rows[$result->id]->rids[] = $result->rid;
@@ -152,31 +195,29 @@ class ResourcesTags extends TagsModelCloud
 
 	/**
 	 * Push group alias into array for easier searching
-	 *
+	 * 
 	 * @param      array $groups User's gorups
 	 * @return     array
 	 */
-	public static function getUsersGroups($groups)
+	public function getUsersGroups($groups)
 	{
 		$arr = array();
-
-		if (!empty($groups))
+		if (!empty($groups)) 
 		{
 			foreach ($groups as $group)
 			{
-				if ($group->regconfirmed)
+				if ($group->regconfirmed) 
 				{
 					$arr[] = $group->cn;
 				}
 			}
 		}
-
 		return $arr;
 	}
 
 	/**
 	 * Get all resources associated with a tag
-	 *
+	 * 
 	 * @param      string  $tag      Tag to find data for
 	 * @param      integer $id       Resource ID
 	 * @param      integer $type     Resource type
@@ -187,17 +228,17 @@ class ResourcesTags extends TagsModelCloud
 	 */
 	public function get_objects_on_tag($tag='', $id=0, $type=0, $sortby='title', $tag2='', $filterby=array())
 	{
-		$juser = JFactory::getUser();
-		$now  = JFactory::getDate()->toSql();
+		$juser =& JFactory::getUser();
+		$now  = date('Y-m-d H:i:s', time());
 
-		if ($tag || $tag2)
+		if ($tag || $tag2) 
 		{
 			$query  = "SELECT C.id, TA.tag, COUNT(DISTINCT TA.tag) AS uniques, ";
-			if ($type == 7)
+			if ($type == 7) 
 			{
 				$query.= "TV.title ";
-			}
-			else
+			} 
+			else 
 			{
 				$query.= "C.title ";
 			}
@@ -211,28 +252,28 @@ class ResourcesTags extends TagsModelCloud
 				break;
 			}
 			$query .= "FROM #__resources AS C ";
-			if ($id)
+			if ($id) 
 			{
 				$query .= "INNER JOIN #__resource_assoc AS RA ON (RA.child_id = C.id AND RA.parent_id=" . $id . ")";
 			}
-			if ($type == 7)
+			if ($type == 7) 
 			{
-				if (!empty($filterby))
+				if (!empty($filterby)) 
 				{
 					$query .= " LEFT JOIN #__resource_taxonomy_audience AS TTA ON C.id=TTA.rid ";
 				}
 				$query .= ", #__tool_version as TV ";
 			}
-			$query .= ", `#__tags_object` AS RTA INNER JOIN #__tags AS TA ON (RTA.tagid = TA.id) ";
-		}
-		else
+			$query .= ", $this->_obj_tbl AS RTA INNER JOIN #__tags AS TA ON (RTA.tagid = TA.id) ";
+		} 
+		else 
 		{
 			$query  = "SELECT C.id,  ";
-			if ($type == 7)
+			if ($type == 7) 
 			{
 				$query .= "TV.title ";
-			}
-			else
+			} 
+			else 
 			{
 				$query .= "C.title ";
 			}
@@ -246,13 +287,13 @@ class ResourcesTags extends TagsModelCloud
 				break;
 			}
 			$query .= "FROM #__resources AS C ";
-			if ($id)
+			if ($id) 
 			{
 				$query .= "INNER JOIN #__resource_assoc AS RA ON (RA.child_id = C.id AND RA.parent_id=" . $id . ")";
 			}
-			if ($type == 7)
+			if ($type == 7) 
 			{
-				if (!empty($filterby))
+				if (!empty($filterby)) 
 				{
 					$query .= " LEFT JOIN #__resource_taxonomy_audience AS TTA ON C.id=TTA.rid ";
 				}
@@ -261,15 +302,15 @@ class ResourcesTags extends TagsModelCloud
 		}
 
 		$query .= "WHERE C.published=1 AND C.standalone=1 ";
-		if ($type)
+		if ($type) 
 		{
 			$query .= "AND C.type=" . $type . " ";
 		}
-		if ($type == 7)
+		if ($type == 7) 
 		{
 			$query .= " AND TV.toolname=C.alias AND TV.state=1 AND TV.revision = (SELECT MAX(revision) FROM #__tool_version as TV WHERE TV.toolname=C.alias AND TV.state=1 GROUP BY TV.toolid) ";
 		}
-		if (!empty($filterby) && $type == 7)
+		if (!empty($filterby) && $type == 7) 
 		{
 			$fquery = " AND ((";
 			for ($i=0, $n=count($filterby); $i < $n; $i++)
@@ -289,17 +330,18 @@ class ResourcesTags extends TagsModelCloud
 		$query .= "AND (C.publish_up = '0000-00-00 00:00:00' OR C.publish_up <= '" . $now . "') ";
 		$query .= "AND (C.publish_down = '0000-00-00 00:00:00' OR C.publish_down >= '" . $now . "') AND ";
 
-		if (!$juser->get('guest'))
+		if (!$juser->get('guest')) 
 		{
-			$xgroups = \Hubzero\User\Helper::getGroups($juser->get('id'), 'all');
-			if ($xgroups != '')
+			ximport('Hubzero_User_Helper');
+			$xgroups = Hubzero_User_Helper::getGroups($juser->get('id'), 'all');
+			if ($xgroups != '') 
 			{
-				$usersgroups = self::getUsersGroups($xgroups);
-				if (count($usersgroups) > 1)
+				$usersgroups = $this->getUsersGroups($xgroups);
+				if (count($usersgroups) > 1) 
 				{
 					$groups = implode("','", $usersgroups);
-				}
-				else
+				} 
+				else 
 				{
 					$groups = count($usersgroups) ? $usersgroups[0] : '';
 				}
@@ -312,26 +354,26 @@ class ResourcesTags extends TagsModelCloud
 			} else {
 				$query .= "(C.access=0 OR C.access=1 OR C.access=3) ";
 			}
-		}
-		else
+		} 
+		else 
 		{
 			$query .= "(C.access=0 OR C.access=3) ";
 		}
-		if ($tag || $tag2)
+		if ($tag || $tag2) 
 		{
-			if ($tag && !$tag2)
+			if ($tag && !$tag2) 
 			{
-				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_scope' AND (TA.tag IN ('" . $tag . "'))";
+				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_tbl' AND (TA.tag IN ('" . $tag . "'))";
 				$query .= " GROUP BY C.id HAVING uniques=1";
-			}
-			else if ($tag2 && !$tag)
+			} 
+			else if ($tag2 && !$tag) 
 			{
-				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_scope' AND (TA.tag IN ('" . $tag2 . "'))";
+				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_tbl' AND (TA.tag IN ('" . $tag2 . "'))";
 				$query .= " GROUP BY C.id HAVING uniques=1";
-			}
-			else if ($tag && $tag2)
+			} 
+			else if ($tag && $tag2) 
 			{
-				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_scope' AND (TA.tag IN ('" . $tag . "','" . $tag2 . "'))";
+				$query .= "AND RTA.objectid=C.id AND RTA.tbl='$this->_tbl' AND (TA.tag IN ('" . $tag . "','" . $tag2 . "'))";
 				$query .= " GROUP BY C.id HAVING uniques=2";
 			}
 		}
@@ -362,7 +404,7 @@ class ResourcesTags extends TagsModelCloud
 
 	/**
 	 * Check if a tag is being used
-	 *
+	 * 
 	 * @param      string  $tag   Tag
 	 * @param      integer $id    Resource ID
 	 * @param      string  $alias Resource alias
@@ -370,27 +412,27 @@ class ResourcesTags extends TagsModelCloud
 	 */
 	public function checkTagUsage($tag, $id=0, $alias='')
 	{
-		if (!$id && !$alias)
+		if (!$id && !$alias) 
 		{
 			return false;
 		}
-		if ($id)
+		if ($id) 
 		{
-			$query = "SELECT COUNT(*)
-						FROM `#__tags_object` AS ta, `#__tags` AS t
-						WHERE ta.tagid=t.id
-						AND t.tag='" . $tag . "'
-						AND ta.tbl='resources'
+			$query = "SELECT COUNT(*) 
+						FROM $this->_obj_tbl AS ta, $this->_tag_tbl AS t 
+						WHERE ta.tagid=t.id 
+						AND t.tag='" . $tag . "' 
+						AND ta.tbl='resources' 
 						AND ta.objectid=" . $id;
 		}
-		if (!$id && $alias)
+		if (!$id && $alias) 
 		{
-			$query = "SELECT COUNT(*)
-						FROM `#__tags_object` AS ta, `#__tags` AS t, `#__resources` AS r
-						WHERE ta.tagid=t.id
-						AND t.tag='" . $tag . "'
-						AND ta.tbl='resources'
-						AND ta.objectid=r.id
+			$query = "SELECT COUNT(*) 
+						FROM $this->_obj_tbl AS ta, $this->_tag_tbl AS t, #__resources AS r 
+						WHERE ta.tagid=t.id 
+						AND t.tag='" . $tag . "' 
+						AND ta.tbl='resources' 
+						AND ta.objectid=r.id 
 						AND r.alias='" . $alias . "'";
 		}
 
@@ -400,232 +442,27 @@ class ResourcesTags extends TagsModelCloud
 
 	/**
 	 * Get a singular field, such as ID, for all items with a specific tag
-	 *
+	 * 
 	 * @param      string $tag  Tag to get data for
 	 * @param      string $rtrn Field to return
 	 * @return     array
 	 */
 	public function getTagUsage($tag, $rtrn='id')
 	{
-		if (!$tag)
+		if (!$tag) 
 		{
 			return array();
 		}
 
-		$query = "SELECT r.$rtrn
-					FROM `#__tags_object` AS ta, `#__tags` AS t, `#__resources` AS r
-					WHERE ta.tagid=t.id
-					AND t.tag='".$tag."'
-					AND ta.tbl='resources'
+		$query = "SELECT r.$rtrn 
+					FROM $this->_obj_tbl AS ta, $this->_tag_tbl AS t, #__resources AS r 
+					WHERE ta.tagid=t.id 
+					AND t.tag='".$tag."' 
+					AND ta.tbl='resources' 
 					AND ta.objectid=r.id";
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadResultArray();
 	}
-
-	/**
-	 * Get a tag cloud for an object
-	 *
-	 * @param      integer $showsizes Show tag size based on use?
-	 * @param      integer $admin     Show admin tags?
-	 * @param      integer $objectid  Object ID
-	 * @return     mixed Return description (if any) ...
-	 */
-	public function getTopTagCloud($limit, $tagstring='')
-	{
-		$t = new TagsTableTag($this->_db);
-		//$tags = $t->getCloud($this->_tbl, $admin, null);
-		$tags = $t->getTopTags($limit, $this->_scope, 'tcount DESC', 0);
-
-		return $this->buildTopCloud($tags, 'alpha', 0, $tagstring);
-	}
-
-	/**
-	 * Get a tag cloud for an object
-	 *
-	 * @param      integer $showsizes Show tag size based on use?
-	 * @param      integer $admin     Show admin tags?
-	 * @param      integer $objectid  Object ID
-	 * @return     mixed Return description (if any) ...
-	 */
-	public function getTopTags($limit)
-	{
-		$t = new TagsTableTag($this->_db);
-		return $t->getTopTags($limit, $this->_scope, 'tcount DESC', 0);
-	}
-
-	/**
-	 * Get a tag cloud for an object
-	 *
-	 * @param      integer $showsizes Show tag size based on use?
-	 * @param      integer $admin     Show admin tags?
-	 * @param      integer $objectid  Object ID
-	 * @return     mixed Return description (if any) ...
-	 */
-	public function getTopTagString($limit)
-	{
-		$t = new TagsTableTag($this->_db);
-
-		$tags = $t->getTopTags($limit, $this->_scope, 'tcount DESC', 0);
-
-		if ($tags && count($tags) > 0)
-		{
-			$tagarray = array();
-			foreach ($tags as $tag)
-			{
-				$tagarray[] = $tag->raw_tag;
-			}
-			$tags = implode(', ', $tagarray);
-		}
-		else
-		{
-			$tags = (is_array($tags)) ? implode('', $tags) : '';
-		}
-		return $tags;
-	}
-
-	/**
-	 * Turn a comma-separated string of tags into an array of normalized tags
-	 *
-	 * @param      string  $tag_string Comma-separated string of tags
-	 * @param      integer $keep       Use normalized tag as array key
-	 * @return     array
-	 */
-	public function parseTags($tag_string, $keep=0)
-	{
-		return $this->_parse($tag_string, $keep);
-	}
-
-	/**
-	 * Turn a string of tags to an array
-	 *
-	 * @param      string $tag Tag string
-	 * @return     mixed
-	 */
-	public function parseTopTags($tag, $remove='')
-	{
-		$bunch = $this->_parse($tag);
-
-		$tags = array();
-		if ($remove)
-		{
-			foreach ($bunch as $t)
-			{
-				if ($remove == $t)
-				{
-					continue;
-				}
-				$tags[] = $t;
-			}
-		}
-		else
-		{
-			return $bunch;
-		}
-
-		return $tags;
-	}
-
-	/**
-	 * Build a tag cloud
-	 *
-	 * @param      array   $tags      List of tags
-	 * @param      string  $sort      How to sort tags?
-	 * @param      integer $showsizes Show tag size based on use?
-	 * @return     string HTML
-	 */
-	public function buildTopCloud($tags, $sort='alpha', $showsizes=0, $tagstring='')
-	{
-		$html = '';
-
-		if ($tags && count($tags) > 0)
-		{
-			$lst = array();
-			if (is_string($tagstring))
-			{
-				$lst = $this->_parse($tagstring);
-			}
-			else
-			{
-				$lst = $tagstring;
-			}
-
-			$min_font_size = 1;
-			$max_font_size = 1.8;
-
-			if ($showsizes)
-			{
-				$retarr = array();
-				foreach ($tags as $tag)
-				{
-					$retarr[$tag->raw_tag] = $tag->count;
-				}
-				ksort($retarr);
-
-				$max_qty = max(array_values($retarr));  // Get the max qty of tagged objects in the set
-				$min_qty = min(array_values($retarr));  // Get the min qty of tagged objects in the set
-
-				// For ever additional tagged object from min to max, we add $step to the font size.
-				$spread = $max_qty - $min_qty;
-				if (0 == $spread)
-				{ // Divide by zero
-					$spread = 1;
-				}
-				$step = ($max_font_size - $min_font_size)/($spread);
-			}
-
-			// build HTML
-			$html .= '<ol class="tags">' . "\n";
-			$tll = array();
-			foreach ($tags as $tag)
-			{
-				$class = '';
-				switch ($tag->admin)
-				{
-					/*case 0:
-						$class = ' class="restricted"';
-					break;*/
-					case 1:
-						$class = ' class="admin"';
-					break;
-				}
-
-				$lsst = $lst;
-
-				if ($tagstring)
-				{
-					if (!in_array($tag->tag, $lst))
-					{
-						$lsst[] = $tag->tag;
-					}
-				}
-				else
-				{
-					$lsst = array($tag->tag);
-				}
-
-				$tag->raw_tag = stripslashes($tag->raw_tag);
-				$tag->raw_tag = str_replace('&amp;', '&', $tag->raw_tag);
-				$tag->raw_tag = str_replace('&', '&amp;', $tag->raw_tag);
-				if ($showsizes == 1)
-				{
-					$size = $min_font_size + ($tag->count - $min_qty) * $step;
-					$tll[$tag->tag] = "\t".'<li' . $class . '><span style="font-size: ' . round($size, 1) . 'em"><a href="' . JRoute::_('index.php?option=com_resources&task=browse&tag=' . implode(',', $lsst)) . '">' . stripslashes($tag->raw_tag) . '</a></li>' . "\n"; //' <span>' . $tag->count . '</span></a></span></li>' . "\n";
-				}
-				else
-				{
-					$tll[$tag->tag] = "\t".'<li' . $class . '><a href="' . urldecode(JRoute::_('index.php?option=com_resources&task=browse&tag=' . implode(',', $lsst))) . '">' . stripslashes($tag->raw_tag) . '</a></li>' . "\n"; //' <span>' . $tag->count . '</span></a></li>' . "\n";
-				}
-			}
-			if ($sort == 'alpha')
-			{
-				ksort($tll);
-				$html .= implode('', $tll);
-			}
-			$html .= '</ol>' . "\n";
-		}
-
-		return $html;
-	}
 }
 
