@@ -32,27 +32,30 @@
 defined('_JEXEC') or die('Restricted access');
 
 /**
- * Whats New helper class for time periods
+ * Short description for 'WhatsnewPeriod'
+ * 
+ * Long description (if any) ...
  */
 class WhatsnewPeriod extends JObject
 {
+
 	/**
 	 * The original search text - should NEVER BE CHANGED
-	 *
+	 * 
 	 * @var string
 	 */
 	private $_period = NULL;
 
 	/**
 	 * Container for storing overloaded data
-	 *
+	 * 
 	 * @var array
 	 */
 	private $_data   = array();
 
 	/**
 	 * Constructor
-	 *
+	 * 
 	 * @param      string $period Time period (month, week, etc)
 	 * @return     void
 	 */
@@ -81,7 +84,7 @@ class WhatsnewPeriod extends JObject
 	 */
 	public function __get($property)
 	{
-		if (isset($this->_data[$property]))
+		if (isset($this->_data[$property])) 
 		{
 			return $this->_data[$property];
 		}
@@ -89,12 +92,12 @@ class WhatsnewPeriod extends JObject
 
 	/**
 	 * Processes the _period text into actual dates
-	 *
+	 * 
 	 * @return     void
 	 */
 	public function process()
 	{
-		if (trim($this->_period) == '')
+		if (trim($this->_period) == '') 
 		{
 			return;
 		}
@@ -102,52 +105,50 @@ class WhatsnewPeriod extends JObject
 		$this->period = $this->_period;
 
 		// Determine last week and last month date
-		//$today = time();
+		$today = time();
 		switch ($this->period)
 		{
 			case 'week':
-				$this->endTime   = JFactory::getDate('now')->toSql(); //$today;
-				$this->startTime = JFactory::getDate('-1 week')->toSql(); //$this->endTime - (7*24*60*60);
+				$this->endTime   = $today;
+				$this->startTime = $this->endTime - (7*24*60*60);
 			break;
 
 			case 'month':
-				$this->endTime   = JFactory::getDate('now')->toSql(); //$today;
-				$this->startTime = JFactory::getDate('-1 month')->toSql(); //$this->endTime - (31*24*60*60);
+				$this->endTime   = $today;
+				$this->startTime = $this->endTime - (31*24*60*60);
 			break;
 
 			case 'quarter':
-				$this->endTime   = JFactory::getDate('now')->toSql(); //$today;
-				$this->startTime = JFactory::getDate('-3 months')->toSql(); //$this->endTime - (3*31*24*60*60);
+				$this->endTime   = $today;
+				$this->startTime = $this->endTime - (3*31*24*60*60);
 			break;
 
 			case 'year':
-				$this->endTime   = JFactory::getDate('now')->toSql(); //$today;
-				$this->startTime = JFactory::getDate('-1 year')->toSql(); //$this->endTime - (365*24*60*60);
+				$this->endTime   = $today;
+				$this->startTime = $this->endTime - (365*24*60*60);
 			break;
 
 			default:
-				if (substr($this->period, 0, 2) == 'c_')
+				if (substr($this->period, 0, 2) == 'c_') 
 				{
 					$tokens = preg_split('/_/', $this->period);
 					$this->period = $tokens[1];
 
 					$this->endTime   = strtotime('12/31/' . $this->period);
 					$this->startTime = strtotime('01/01/' . $this->period);
-				}
-				else
+				} 
+				else 
 				{
 					$this->endTime   = strtotime('08/31/' . $this->period);
 					$this->startTime = strtotime('09/01/' . ($this->period-1));
 				}
-				$this->endTime   = date("Y-m-d H:i:s", $this->endTime);
-				$this->startTime = date("Y-m-d H:i:s", $this->startTime);
 			break;
 		}
 
-		$this->cStartDate = $this->startTime; //date("Y-m-d H:i:s", $this->startTime);
-		$this->dStartDate = substr($this->startTime, 0, strlen('0000-00-00')); //date("Y-m-d", $this->startTime);
-		$this->cEndDate   = $this->endTime; //date("Y-m-d H:i:s", $this->endTime);
-		$this->dEndDate   = substr($this->endTime, 0, strlen('0000-00-00')); //date("Y-m-d", $this->endTime);
+		$this->cStartDate = date("Y-m-d H:i:s", $this->startTime);
+		$this->dStartDate = date("Y-m-d", $this->startTime);
+		$this->cEndDate   = date("Y-m-d H:i:s", $this->endTime);
+		$this->dEndDate   = date("Y-m-d", $this->endTime);
 	}
 }
 
